glue\_genes.glue\_single\_cell.qt.summarize\_gene\_subset.do\_calculation\_over\_gene\_subset
=============================================================================================

.. currentmodule:: glue_genes.glue_single_cell.qt.summarize_gene_subset

.. autofunction:: do_calculation_over_gene_subset